@@ -1,8 +1,7 @@
 from __future__ import unicode_literals
 import pytest
 
-from ..predicate import (
-    match_instance, match_key, match_class, key_predicate, NOT_FOUND)
+from ..predicate import match_instance, match_key, match_class
 from ..dispatch import dispatch
 from ..error import RegistrationError
 
@@ -85,10 +84,10 @@ def test_dispatch_no_arguments():
 
     foo.register(special_foo)
 
-    assert foo.component() is special_foo
-    assert list(foo.all()) == [special_foo]
+    assert foo.by_args().component is special_foo
+    assert foo.by_args().all_matches == [special_foo]
     assert foo() == 'special'
-    assert foo.fallback() is None
+    assert foo.by_args().fallback is None
 
 
 def test_all():
@@ -114,9 +113,9 @@ def test_all():
     base = Base()
     sub = Sub()
 
-    assert list(target.all(sub)) == [
+    assert target.by_args(sub).all_matches == [
         registered_for_sub, registered_for_base]
-    assert list(target.all(base)) == [
+    assert target.by_args(base).all_matches == [
         registered_for_base]
 
 
@@ -140,9 +139,9 @@ def test_all_by_keys():
     target.register(registered_for_sub, obj=Sub)
     target.register(registered_for_base, obj=Base)
 
-    assert list(target.all_by_keys(obj=Sub)) == [
+    assert target.by_predicates(obj=Sub).all_matches == [
         registered_for_sub, registered_for_base]
-    assert list(target.all_by_keys(obj=Base)) == [
+    assert target.by_predicates(obj=Base).all_matches == [
         registered_for_base]
 
 
@@ -155,7 +154,7 @@ def test_component_no_source():
         pass
 
     target.register(foo)
-    assert target.component() is foo
+    assert target.by_args().component is foo
 
 
 def test_component_no_source_key_dict():
@@ -167,7 +166,7 @@ def test_component_no_source_key_dict():
         pass
 
     target.register(foo)
-    assert target.component_by_keys() is foo
+    assert target.by_predicates().component is foo
 
 
 def test_component_one_source():
@@ -181,7 +180,7 @@ def test_component_one_source():
     target.register(foo, obj=Alpha)
 
     alpha = Alpha()
-    assert target.component(alpha) is foo
+    assert target.by_args(alpha).component is foo
 
 
 def test_component_one_source_key_dict():
@@ -194,7 +193,7 @@ def test_component_one_source_key_dict():
 
     target.register(foo, obj=Alpha)
 
-    assert target.component_by_keys(obj=Alpha) is foo
+    assert target.by_predicates(obj=Alpha).component is foo
 
 
 def test_component_two_sources():
@@ -209,7 +208,7 @@ def test_component_two_sources():
 
     alpha = Alpha()
     beta = Beta()
-    assert target.component(alpha, beta) is foo
+    assert target.by_args(alpha, beta).component is foo
 
 
 def test_component_inheritance():
@@ -230,7 +229,7 @@ def test_component_inheritance():
 
     delta = Delta()
 
-    assert target.component(delta) is foo
+    assert target.by_args(delta).component is foo
 
 
 def test_component_inheritance_old_style_class():
@@ -252,10 +251,10 @@ def test_component_inheritance_old_style_class():
     gamma = Gamma()
     delta = Delta()
 
-    assert target.component(gamma) is foo
+    assert target.by_args(gamma).component is foo
 
     # inheritance case
-    assert target.component(delta) is foo
+    assert target.by_args(delta).component is foo
 
 
 def test_call_no_source():
@@ -316,7 +315,7 @@ def test_component_not_found_no_sources():
     def target():
         pass
 
-    assert target.component() is None
+    assert target.by_args().component is None
 
 
 def test_call_not_found_no_sources():
@@ -332,7 +331,7 @@ def test_component_not_found_one_source():
     def target(obj):
         pass
 
-    assert target.component('dummy') is None
+    assert target.by_args('dummy').component is None
 
 
 def test_call_not_found_one_source():
@@ -348,7 +347,7 @@ def test_component_not_found_two_sources():
     def target(a, b):
         pass
 
-    assert target.component('dummy', 'dummy') is None
+    assert target.by_args('dummy', 'dummy').component is None
 
 
 def test_call_not_found_two_sources():
@@ -397,7 +396,7 @@ def test_call_with_no_args_while_arg_expected():
         target()
 
     with pytest.raises(TypeError):
-        target.component()
+        target.by_args().component
 
 
 def test_call_with_wrong_args():
@@ -415,7 +414,7 @@ def test_call_with_wrong_args():
         target(wrong=1)
 
     with pytest.raises(TypeError):
-        target.component(wrong=1)
+        target.by_args(wrong=1)
 
 
 def test_extra_arg_for_call():
@@ -454,10 +453,10 @@ def test_fallback_to_fallback():
     beta = Beta()
     assert target(beta) == 'fallback!'
     # this is *not* a registered fallback so won't be returned here
-    assert target.fallback(beta) is fallback
+    assert target.by_args(beta).fallback is fallback
     # we cannot find a fallback for alpha, as it doesn't hit the fallback
     assert target(Alpha()) == 'specific'
-    assert target.fallback(Alpha()) is NOT_FOUND
+    assert target.by_args(Alpha()).fallback is None
 
 
 def test_fallback_to_dispatch():
@@ -473,7 +472,7 @@ def test_fallback_to_dispatch():
     beta = Beta()
     assert target(beta) == 'fallback'
     # this is *not* a registered fallback so won't be returned here
-    assert target.fallback(beta) is None
+    assert target.by_args(beta).fallback is None
 
 
 def test_calling_twice():
@@ -508,7 +507,7 @@ def test_different_defaults_in_specific_non_dispatch_arg():
 
 
 def test_different_defaults_in_specific_dispatch_arg():
-    @dispatch(match_key('key', lambda key: key))
+    @dispatch(match_key('key'))
     def target(key='default'):
         return 'fallback: %s' % key
 
@@ -523,7 +522,7 @@ def test_different_defaults_in_specific_dispatch_arg():
 
 
 def test_different_defaults_in_specific_dispatch_arg_causes_dispatch():
-    @dispatch(match_key('key', lambda key: key))
+    @dispatch(match_key('key'))
     def target(key='foo'):
         return 'fallback: %s' % key
 
@@ -667,7 +666,7 @@ def test_dispatch_external_predicates():
     assert view(Foo(), Request('dummy', 'GET')) == 'Name fallback'
     assert view(Foo(), Request('', 'PUT')) == 'Request method fallback'
     assert view(FooSub(), Request('dummy', 'GET')) == 'Name fallback'
-    assert view.fallback(Bar(), Request('', 'GET')) is model_fallback
+    assert view.by_args(Bar(), Request('', 'GET')).fallback is model_fallback
 
 
 def test_dispatch_predicates_register_defaults():
@@ -741,30 +740,25 @@ def test_dispatch_predicates_register_defaults():
 
 def test_key_dict_to_predicate_key():
     @dispatch(
-        key_predicate('foo', default='default foo'),
-        key_predicate('bar', default='default bar'))
+        match_key('foo', default='default foo'),
+        match_key('bar', default='default bar'))
     def view(self, request):
         raise NotImplementedError()
 
-    assert view.key_dict_to_predicate_key({
-        'foo': 'FOO',
-        'bar': 'BAR'}) == ('FOO', 'BAR')
-    assert view.key_dict_to_predicate_key({}) == (
-        'default foo',
-        'default bar')
+    assert view.by_predicates(foo='FOO', bar='BAR').key == ('FOO', 'BAR')
+    assert view.by_predicates().key == ('default foo', 'default bar')
 
 
 def test_key_dict_to_predicate_key_unknown_keys():
     @dispatch(
-        key_predicate('foo', default='default foo'),
-        key_predicate('bar', default='default bar'))
+        match_key('foo', default='default foo'),
+        match_key('bar', default='default bar'))
     def view(self, request):
         raise NotImplementedError()
 
     # unknown keys are just ignored
-    assert view.key_dict_to_predicate_key({'unknown': 'blah'}) == (
-        'default foo',
-        'default bar')
+    assert view.by_predicates(unknown='blah').key == \
+        ('default foo', 'default bar')
 
 
 def test_register_dispatch_key_dict():
@@ -805,7 +799,7 @@ def test_register_dispatch_key_dict():
                   request_method_fallback,
                   default='GET')])
 
-    assert view.key_dict_to_predicate_key({}) == (None, '', 'GET')
+    assert view.by_predicates().key == (None, '', 'GET')
 
 
 def test_fallback_should_already_use_subset():
@@ -871,11 +865,12 @@ def test_fallback_should_already_use_subset():
         model=Collection, request_method='POST',
         body_model=Item)
 
-    assert view.fallback(Collection(),
-                         Request('', 'POST', Item2()),
-                         ) is body_model_fallback
-    assert view(Collection(), Request('', 'POST', Item2()),
-                ) == 'Body model fallback'
+    assert view.by_args(
+        Collection(), Request('', 'POST', Item2()),
+    ).fallback is body_model_fallback
+    assert view(
+        Collection(), Request('', 'POST', Item2()),
+    ) == 'Body model fallback'
 
 
 def test_dispatch_missing_argument():
@@ -926,7 +921,7 @@ def test_dict_to_predicate_key_for_no_dispatch():
     def foo():
         pass
 
-    assert foo.key_dict_to_predicate_key({}) == ()
+    assert foo.by_predicates().key == ()
 
 
 def test_dispatch_clean():
@@ -1042,7 +1037,7 @@ def test_component_lookup_before_call_and_no_registrations():
     class Bar(object):
         pass
 
-    assert foo.component(Bar()) is None
+    assert foo.by_args(Bar()).component is None
 
 
 def test_predicate_key_too_few_arguments_gives_typeerror():
@@ -1057,7 +1052,7 @@ def test_predicate_key_too_few_arguments_gives_typeerror():
         return obj.method()
 
     with pytest.raises(TypeError):
-        assert foo.predicate_key()
+        assert foo.by_args()
 
 
 def test_predicate_key_too_many_arguments_gives_typeerror():
@@ -1072,7 +1067,7 @@ def test_predicate_key_too_many_arguments_gives_typeerror():
         return obj.method()
 
     with pytest.raises(TypeError):
-        assert foo.predicate_key(1, 2)
+        assert foo.by_args(1, 2)
 
 
 def test_predicate_key_wrong_keyword_argument_gives_typeerror():
@@ -1087,4 +1082,4 @@ def test_predicate_key_wrong_keyword_argument_gives_typeerror():
         return obj.method()
 
     with pytest.raises(TypeError):
-        assert foo.predicate_key(wrong=1)
+        assert foo.by_args(wrong=1)
